/*
 * Copyright 2009-2013 by The Regents of the University of California
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * you may obtain a copy of the License from
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package edu.uci.ics.asterix.aql.expression;

import java.util.List;
import java.util.Map;

import edu.uci.ics.asterix.metadata.bootstrap.MetadataConstants;

public class InternalDetailsDecl implements IDatasetDetailsDecl {
    private final Identifier nodegroupName;
    private final List<String> partitioningExprs;
    private final boolean autogenerated;
    private final String compactionPolicy;
    private final Map<String, String> compactionPolicyProperties;
    private final String filterField;

    public InternalDetailsDecl(Identifier nodeGroupName, List<String> partitioningExpr, boolean autogenerated,
            String compactionPolicy, Map<String, String> compactionPolicyProperties, String filterField) {
        this.nodegroupName = nodeGroupName == null ? new Identifier(MetadataConstants.METADATA_DEFAULT_NODEGROUP_NAME)
                : nodeGroupName;
        this.partitioningExprs = partitioningExpr;
        this.autogenerated = autogenerated;
        this.compactionPolicy = compactionPolicy;
        this.compactionPolicyProperties = compactionPolicyProperties;
        this.filterField = filterField;
    }

    public List<String> getPartitioningExprs() {
        return partitioningExprs;
    }

    @Override
    public Identifier getNodegroupName() {
        return nodegroupName;
    }

    public boolean isAutogenerated() {
        return autogenerated;
    }

    @Override
    public String getCompactionPolicy() {
        return compactionPolicy;
    }

    @Override
    public Map<String, String> getCompactionPolicyProperties() {
        return compactionPolicyProperties;
    }

    public String getFilterField() {
        return filterField;
    }

}
